TokenBucket

Struct TokenBucket 

pub struct TokenBucket<T>
where T: Fn() -> Duration,
{ /* private fields */ }
Token bucket -type rate limiter

A token bucket limiter can be illustrated as a being filled with tokens at a constant rate, while consumes will remove tokens from the bucket.

This leads to a soft limiter where occasional burstiness is allowed since as long as the bucket holds tokens those can be consumed at an unlimited rate. Ultimately the bucket size is what defined the burstiness.

Implementations

Source

impl<T> TokenBucket<T>
where T: Fn() -> Duration,

pub fn new_with_time_provider( rate_per_s: u64, capacity: u64, time_provider: T, ) -> Self

Initialize a new token bucket utilizing the given timer

Arguments
  • rate_per_sec - how many consumes should be allowed per second on average
  • capacity - bucket capacity to dictate the burstiness of this limiter
  • time_provider_t - closure that returns a monotonically nondecreasing timestamp as Duration from some fixed epoch in the past

If you are developing for a std target, you probably wish to use token_bucket